#!/bin/sh
#
# crontab や VRS でこのスクリプトを使う場合は以下の環境変数を設定すること
# crontab で動かすときは www-data( apache )ユーザで動かさないと kill -INT 出来ないので注意
#
# (1) 常に設定する必要がある変数
#
# HOMEDIR=  # config.php で設定する 'HOME'
# STATDIR=  # config-recfriio.php で設定する 'STATDIR'
# STATBASE= # config-recfriio.php で設定する 'STATBASE'
#
# (2) VRS で使うときは指定不要な変数 ( VRS が値を渡すので )
#
# CHANNEL=   # チャンネル
# DURATION=  # 録画秒数
# OUTDIR=    # 保存先ディレクトリ
# OUTNAME=   # ファイル名 ( crontab で使用する時は上書き防止に日付も入れると良いかも )
#
# (3) UDP 送信する場合に必要な変数 (お好みで)
#
# recfriio の --udp オプションは HDUSパッチを当てないと無効なので注意
#
# UDP= # 使用する場合は 1 をセット
# IP=
# PORT=

# 現在時刻取得
STARTTIME=`date +%s`

# 設定
RECFRIIO=/usr/bin/recfriio
HDUS=--hdus
B25=--b25
EXT=.ts

# UDP 送信
if [ "$UDP" = 1 ];
then
OPTUDP="--udp $IP --port $PORT"
fi

# 出力ファイル名
if [ "$OUTNAME" = "/dev/null" ];
then
FILENAME=/dev/null
else
FILENAME="$OUTDIR/$OUTNAME$EXT"
fi

# 実行
$RECFRIIO $HDUS $B25 $OPTUDP $CHANNEL $DURATION $FILENAME & > /dev/null

# 以下は recfriio server と同期を取るための処理
# STATUSFILE に動作状況を書き込んで recfriio server が読み込む

# PID を取得してステータスファイル(csv形式)に出力
PID=$!
LINE="$PID,$CHANNEL,$STARTTIME,$DURATION,$OUTDIR,$OUTNAME,$UDP,$IP,$PORT"
STATUSFILE="$HOMEDIR$STATDIR/$STATBASE-$PID"
echo $LINE > $STATUSFILE

# 録画が終わるまで待ってステータスファイルを削除
wait $PID
rm $STATUSFILE
